@@ -822,7 +822,7 @@ function import_products($HTTP_POST_FILES) {
 
 			/* ... and let's see if the product already exists ... */
 			$qid = db_query("
-			SELECT id, name FROM products WHERE id = '$fldarr[1]'
+			SELECT id FROM products WHERE id = '$fldarr[1]'
 			");
 			if (db_num_rows($qid) == 0) {
 				/* ... if it doesn't exist let's create it in the products table ... */
