@@ -12,8 +12,8 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 
 /******************************************************************************
  * MAIN
@@ -47,40 +47,40 @@ switch (nvl($mode)) {
 		break;
 
 	case "insert" :
-        	$errors = new Object;
-        	$errormsg = "";
-        	validate_username($HTTP_POST_VARS["username"], &$errors, &$errormsg);
-        	validate_priv($HTTP_POST_VARS["priv"], &$errors, &$errormsg);
+		$errors = new Object;
+		$errormsg = "";
+		validate_username($HTTP_POST_VARS["username"], &$errors, &$errormsg);
+		validate_priv($HTTP_POST_VARS["priv"], &$errors, &$errormsg);
 		if ($HTTP_POST_VARS["usertype"] == "pf") {
-        		validate_firstname($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
-        		validate_lastname($HTTP_POST_VARS["lastname"], &$errors, &$errormsg);
+			validate_firstname($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
+			validate_lastname($HTTP_POST_VARS["lastname"], &$errors, &$errormsg);
 			if (!empty($HTTP_POST_VARS["fiscalcode"])) {
-        			validate_fiscalcode($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
+				validate_fiscalcode($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
 			}
 		} else if ($HTTP_POST_VARS["usertype"] == "az") {
 			validate_ragionesociale($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
 			validate_partitaiva($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
 		}
-        	validate_address($HTTP_POST_VARS["address"], &$errors, &$errormsg);
-        	validate_number($HTTP_POST_VARS["number"], &$errors, &$errormsg);
-        	validate_city($HTTP_POST_VARS["city"], &$errors, &$errormsg);
-        	validate_state($HTTP_POST_VARS["state"], &$errors, &$errormsg);
-        	validate_zip_code($HTTP_POST_VARS["zip_code"], &$errors, &$errormsg);
-        	validate_phone($HTTP_POST_VARS["phone"], &$errors, &$errormsg);
-        	validate_fax($HTTP_POST_VARS["fax"], &$errors, &$errormsg);
-        	validate_mobilephone($HTTP_POST_VARS["mobilephone"], &$errors, &$errormsg);
-        	validate_email($HTTP_POST_VARS["email"], &$errors, &$errormsg);
-        	validate_notes($HTTP_POST_VARS["notes"], &$errors, &$errormsg);
-        	validate_ournotes($HTTP_POST_VARS["ournotes"], &$errors, &$errormsg);
+		validate_address($HTTP_POST_VARS["address"], &$errors, &$errormsg);
+		validate_number($HTTP_POST_VARS["number"], &$errors, &$errormsg);
+		validate_city($HTTP_POST_VARS["city"], &$errors, &$errormsg);
+		validate_country($HTTP_POST_VARS["country"], &$errors, &$errormsg);
+		validate_zip_code($HTTP_POST_VARS["zip_code"], &$errors, &$errormsg);
+		validate_phone($HTTP_POST_VARS["phone"], &$errors, &$errormsg);
+		validate_fax($HTTP_POST_VARS["fax"], &$errors, &$errormsg);
+		validate_mobilephone($HTTP_POST_VARS["mobilephone"], &$errors, &$errormsg);
+		validate_email($HTTP_POST_VARS["email"], &$errors, &$errormsg);
+		validate_notes($HTTP_POST_VARS["notes"], &$errors, &$errormsg);
+		validate_ournotes($HTTP_POST_VARS["ournotes"], &$errors, &$errormsg);
 		if (username_exists($HTTP_POST_VARS["username"])) {
 			$errors->username = true;
 			$errormsg = "<li>" . $the_username . " <b>" . ov($HTTP_POST_VARS["username"]) ."</b> " . $already_exists . $errormsg;
 		}
 /*
-        	if (email_exists($HTTP_POST_VARS["email"])) {
-                	$errors->email = true;
-                	$errormsg .= "<li>" . $the_email_address . " <b>" . ov($HTTP_POST_VARS["email"]) ."</b> " . $already_exists;
-        	}
+		if (email_exists($HTTP_POST_VARS["email"])) {
+			$errors->email = true;
+			$errormsg .= "<li>" . $the_email_address . " <b>" . ov($HTTP_POST_VARS["email"]) ."</b> " . $already_exists;
+		}
 */
 		if (empty($errormsg)) {
 			insert_user($HTTP_POST_VARS);
@@ -95,7 +95,7 @@ switch (nvl($mode)) {
 			$frm["address"] = $HTTP_POST_VARS["address"];
 			$frm["number"] = $HTTP_POST_VARS["number"];
 			$frm["city"] = $HTTP_POST_VARS["city"];
-			$frm["state"] = $HTTP_POST_VARS["state"];
+			$frm["country"] = $HTTP_POST_VARS["country"];
 			$frm["zip_code"] = $HTTP_POST_VARS["zip_code"];
 			$frm["phone"] = $HTTP_POST_VARS["phone"];
 			$frm["fax"] = $HTTP_POST_VARS["fax"];
@@ -113,36 +113,36 @@ switch (nvl($mode)) {
 		break;
 
 	case "update" :
-        	$errors = new Object;
-        	$errormsg = "";
-        	validate_priv($HTTP_POST_VARS["priv"], &$errors, &$errormsg);
+		$errors = new Object;
+		$errormsg = "";
+		validate_priv($HTTP_POST_VARS["priv"], &$errors, &$errormsg);
 		if ($HTTP_POST_VARS["usertype"] == "pf") {
-        		validate_firstname($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
-        		validate_lastname($HTTP_POST_VARS["lastname"], &$errors, &$errormsg);
+			validate_firstname($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
+			validate_lastname($HTTP_POST_VARS["lastname"], &$errors, &$errormsg);
 			if (!empty($HTTP_POST_VARS["fiscalcode"])) {
-        			validate_fiscalcode($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
+				validate_fiscalcode($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
 			}
 		} else if ($HTTP_POST_VARS["usertype"] == "az") {
 			validate_ragionesociale($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
 			validate_partitaiva($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
 		}
-        	validate_address($HTTP_POST_VARS["address"], &$errors, &$errormsg);
-        	validate_number($HTTP_POST_VARS["number"], &$errors, &$errormsg);
-        	validate_city($HTTP_POST_VARS["city"], &$errors, &$errormsg);
-        	validate_state($HTTP_POST_VARS["state"], &$errors, &$errormsg);
-        	validate_zip_code($HTTP_POST_VARS["zip_code"], &$errors, &$errormsg);
-        	validate_phone($HTTP_POST_VARS["phone"], &$errors, &$errormsg);
-        	validate_fax($HTTP_POST_VARS["fax"], &$errors, &$errormsg);
-        	validate_mobilephone($HTTP_POST_VARS["mobilephone"], &$errors, &$errormsg);
-        	validate_email($HTTP_POST_VARS["email"], &$errors, &$errormsg);
-        	validate_notes($HTTP_POST_VARS["notes"], &$errors, &$errormsg);
-        	validate_ournotes($HTTP_POST_VARS["ournotes"], &$errors, &$errormsg);
+		validate_address($HTTP_POST_VARS["address"], &$errors, &$errormsg);
+		validate_number($HTTP_POST_VARS["number"], &$errors, &$errormsg);
+		validate_city($HTTP_POST_VARS["city"], &$errors, &$errormsg);
+		validate_country($HTTP_POST_VARS["country"], &$errors, &$errormsg);
+		validate_zip_code($HTTP_POST_VARS["zip_code"], &$errors, &$errormsg);
+		validate_phone($HTTP_POST_VARS["phone"], &$errors, &$errormsg);
+		validate_fax($HTTP_POST_VARS["fax"], &$errors, &$errormsg);
+		validate_mobilephone($HTTP_POST_VARS["mobilephone"], &$errors, &$errormsg);
+		validate_email($HTTP_POST_VARS["email"], &$errors, &$errormsg);
+		validate_notes($HTTP_POST_VARS["notes"], &$errors, &$errormsg);
+		validate_ournotes($HTTP_POST_VARS["ournotes"], &$errors, &$errormsg);
 /*
-        	if ($HTTP_POST_VARS["old_email"] != $HTTP_POST_VARS["email"]
+		if ($HTTP_POST_VARS["old_email"] != $HTTP_POST_VARS["email"]
 		     && email_exists($HTTP_POST_VARS["email"])) {
-                	$errors->email = true;
-                	$errormsg .= "<li>" . $the_email_address . " <b>" . ov($HTTP_POST_VARS["email"]) ."</b> " . $already_exists;
-        	}
+			$errors->email = true;
+			$errormsg .= "<li>" . $the_email_address . " <b>" . ov($HTTP_POST_VARS["email"]) ."</b> " . $already_exists;
+		}
 */
 		if (empty($errormsg)) {
 			update_user($HTTP_POST_VARS);
@@ -157,7 +157,7 @@ switch (nvl($mode)) {
 			$frm["address"] = $HTTP_POST_VARS["address"];
 			$frm["number"] = $HTTP_POST_VARS["number"];
 			$frm["city"] = $HTTP_POST_VARS["city"];
-			$frm["state"] = $HTTP_POST_VARS["state"];
+			$frm["country"] = $HTTP_POST_VARS["country"];
 			$frm["zip_code"] = $HTTP_POST_VARS["zip_code"];
 			$frm["phone"] = $HTTP_POST_VARS["phone"];
 			$frm["fax"] = $HTTP_POST_VARS["fax"];
@@ -238,7 +238,7 @@ function print_add_user_form($usertype) {
 	$frm["address"] = "";
 	$frm["number"] = "";
 	$frm["city"] = "";
-	$frm["state"] = "";
+	$frm["country"] = "";
 	$frm["zip_code"] = "";
 	$frm["phone"] = "";
 	$frm["fax"] = "";
@@ -318,7 +318,7 @@ function insert_user($frm) {
 		,address
 		,number
 		,city
-		,state
+		,country
 		,zip_code
 		,phone
 		,fax
@@ -342,7 +342,7 @@ function insert_user($frm) {
 		,'$frm[address]'
 		,'$frm[number]'
 		,'$frm[city]'
-		,'$frm[state]'
+		,'$frm[country]'
 		,'$frm[zip_code]'
 		,'$frm[phone]'
 		,'$frm[fax]'
@@ -375,7 +375,7 @@ function update_user($frm) {
 		,address = '$frm[address]'
 		,number = '$frm[number]'
 		,city = '$frm[city]'
-		,state = '$frm[state]'
+		,country = '$frm[country]'
 		,zip_code = '$frm[zip_code]'
 		,phone = '$frm[phone]'
 		,fax = '$frm[fax]'
@@ -460,43 +460,9 @@ function import_users($userfile) {
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 //echo "<b>" . $line_num . "</b>:" . $line . "<br>";
-		/* Stripping dangerous characters from fields */
-		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
-		$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
-		$fldarr[2] = ereg_replace("\'","",$fldarr[2]);
-		$fldarr[3] = ereg_replace("\'","",$fldarr[3]);
-//		$fldarr[4] = ereg_replace("\'","",$fldarr[4]);
-		$fldarr[4] = ereg_replace("'","\'",$fldarr[4]);
-		$fldarr[4] = ereg_replace("\"","\\\"",$fldarr[4]);
-//		$fldarr[5] = ereg_replace("\'","",$fldarr[5]);
-		$fldarr[5] = ereg_replace("'","\'",$fldarr[5]);
-		$fldarr[5] = ereg_replace("\"","\\\"",$fldarr[5]);
-		$fldarr[6] = ereg_replace("\'","",$fldarr[6]);
-//		$fldarr[7] = ereg_replace("\'","",$fldarr[7]);
-		$fldarr[7] = ereg_replace("'","\'",$fldarr[7]);
-		$fldarr[7] = ereg_replace("\"","\\\"",$fldarr[7]);
-		$fldarr[8] = ereg_replace("\'","",$fldarr[8]);
-//		$fldarr[9] = ereg_replace("\'","",$fldarr[9]);
-		$fldarr[9] = ereg_replace("'","\'",$fldarr[9]);
-		$fldarr[9] = ereg_replace("\"","\\\"",$fldarr[9]);
-//		$fldarr[10] = ereg_replace("\'","",$fldarr[10]);
-		$fldarr[10] = ereg_replace("'","\'",$fldarr[10]);
-		$fldarr[10] = ereg_replace("\"","\\\"",$fldarr[10]);
-		$fldarr[11] = ereg_replace("\'","",$fldarr[11]);
-		$fldarr[12] = ereg_replace("\'","",$fldarr[12]);
-		$fldarr[13] = ereg_replace("\'","",$fldarr[13]);
-		$fldarr[14] = ereg_replace("\'","",$fldarr[14]);
-		$fldarr[15] = ereg_replace("\'","",$fldarr[15]);
-		$fldarr[16] = ereg_replace("\'","",$fldarr[16]);
-		$fldarr[17] = ereg_replace("\'","",$fldarr[17]);
-//		$fldarr[18] = ereg_replace("\'","",$fldarr[18]);
-		$fldarr[18] = ereg_replace("'","\'",$fldarr[18]);
-		$fldarr[18] = ereg_replace("\"","\\\"",$fldarr[18]);
-//		$fldarr[19] = ereg_replace("\'","",$fldarr[19]);
-		$fldarr[19] = ereg_replace("'","\'",$fldarr[19]);
-		$fldarr[19] = ereg_replace("\"","\\\"",$fldarr[19]);
-		$fldarr[20] = ereg_replace("\'","",$fldarr[20]);
-		$fldarr[21] = ereg_replace("\'","",$fldarr[21]);
+		/* dangerous characters quoting */
+		for ($i=0; $i<22; $i++)
+			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the user already exists ... */
 		$qid = db_query("
@@ -516,7 +482,7 @@ function import_users($userfile) {
 				,address
 				,number
 				,city
-				,state
+				,country
 				,zip_code
 				,phone
 				,fax
@@ -566,7 +532,7 @@ function import_users($userfile) {
 				,address = '$fldarr[7]'
 				,number = '$fldarr[8]'
 				,city = '$fldarr[9]'
-				,state = '$fldarr[10]'
+				,country = '$fldarr[10]'
 				,zip_code = '$fldarr[11]'
 				,phone = '$fldarr[12]'
 				,fax = '$fldarr[13]'
