@@ -25,7 +25,8 @@ function db_connect($dbhost, $port, $dbname, $dbuser, $dbpass) {
 
 	global $DB_DIE_ON_FAIL, $DB_DEBUG;
 
-	if (!($dbh = pg_pconnect("host=$dbhost port=$port user=$dbuser password=$dbpass dbname=$dbname"))) {
+//	if (!($dbh = pg_pconnect("host=$dbhost port=$port user=$dbuser password=$dbpass dbname=$dbname"))) {
+	if (!($dbh = pg_connect("host=$dbhost port=$port user=$dbuser password=$dbpass dbname=$dbname"))) {
 		if ($DB_DEBUG) {
 			echo "<h2>Can't connect to $dbhost as $dbuser</h2>";
 //			echo "<p><b>MySQL Error</b>: ", db_error();
