@@ -1,6 +1,6 @@
 <?
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua> */
 
 include("../application.inc.php");
@@ -22,7 +22,7 @@ if (!isset($page_number) || $dbchanged) {
 	}
 }
 
-$DOC_TITLE = $Shopping_Catalog;
+$DOC_TITLE = $Search_Results;
 $SESSION["goback"]["request_uri"] = $REQUEST_URI;
 $SESSION["goback"]["query_string"] = $QUERY_STRING;
 include("$CFG->templatedir"."header.ihtml");
